pitchtools.NumberedInterval
===========================

.. abjad-lineage:: abjad.tools.pitchtools.NumberedInterval.NumberedInterval.NumberedInterval

.. autoclass:: abjad.tools.pitchtools.NumberedInterval.NumberedInterval.NumberedInterval

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.pitchtools.NumberedInterval.NumberedInterval.NumberedInterval.cents
      ~abjad.tools.pitchtools.NumberedInterval.NumberedInterval.NumberedInterval.direction_number
      ~abjad.tools.pitchtools.NumberedInterval.NumberedInterval.NumberedInterval.direction_string
      ~abjad.tools.pitchtools.NumberedInterval.NumberedInterval.NumberedInterval.from_pitch_carriers
      ~abjad.tools.pitchtools.NumberedInterval.NumberedInterval.NumberedInterval.interval_class
      ~abjad.tools.pitchtools.NumberedInterval.NumberedInterval.NumberedInterval.is_named_interval_abbreviation
      ~abjad.tools.pitchtools.NumberedInterval.NumberedInterval.NumberedInterval.is_named_interval_quality_abbreviation
      ~abjad.tools.pitchtools.NumberedInterval.NumberedInterval.NumberedInterval.number
      ~abjad.tools.pitchtools.NumberedInterval.NumberedInterval.NumberedInterval.numbered_interval_number
      ~abjad.tools.pitchtools.NumberedInterval.NumberedInterval.NumberedInterval.semitones
      ~abjad.tools.pitchtools.NumberedInterval.NumberedInterval.NumberedInterval.__abs__
      ~abjad.tools.pitchtools.NumberedInterval.NumberedInterval.NumberedInterval.__add__
      ~abjad.tools.pitchtools.NumberedInterval.NumberedInterval.NumberedInterval.__copy__
      ~abjad.tools.pitchtools.NumberedInterval.NumberedInterval.NumberedInterval.__eq__
      ~abjad.tools.pitchtools.NumberedInterval.NumberedInterval.NumberedInterval.__float__
      ~abjad.tools.pitchtools.NumberedInterval.NumberedInterval.NumberedInterval.__ge__
      ~abjad.tools.pitchtools.NumberedInterval.NumberedInterval.NumberedInterval.__gt__
      ~abjad.tools.pitchtools.NumberedInterval.NumberedInterval.NumberedInterval.__hash__
      ~abjad.tools.pitchtools.NumberedInterval.NumberedInterval.NumberedInterval.__int__
      ~abjad.tools.pitchtools.NumberedInterval.NumberedInterval.NumberedInterval.__le__
      ~abjad.tools.pitchtools.NumberedInterval.NumberedInterval.NumberedInterval.__lt__
      ~abjad.tools.pitchtools.NumberedInterval.NumberedInterval.NumberedInterval.__ne__
      ~abjad.tools.pitchtools.NumberedInterval.NumberedInterval.NumberedInterval.__neg__
      ~abjad.tools.pitchtools.NumberedInterval.NumberedInterval.NumberedInterval.__repr__
      ~abjad.tools.pitchtools.NumberedInterval.NumberedInterval.NumberedInterval.__str__
      ~abjad.tools.pitchtools.NumberedInterval.NumberedInterval.NumberedInterval.__sub__

Bases
-----

- :py:class:`pitchtools.Interval <abjad.tools.pitchtools.Interval.Interval.Interval>`

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.pitchtools.NumberedInterval.NumberedInterval.NumberedInterval.cents
   :noindex:

.. autoattribute:: abjad.tools.pitchtools.NumberedInterval.NumberedInterval.NumberedInterval.direction_number
   :noindex:

.. autoattribute:: abjad.tools.pitchtools.NumberedInterval.NumberedInterval.NumberedInterval.direction_string
   :noindex:

.. autoattribute:: abjad.tools.pitchtools.NumberedInterval.NumberedInterval.NumberedInterval.interval_class
   :noindex:

.. autoattribute:: abjad.tools.pitchtools.NumberedInterval.NumberedInterval.NumberedInterval.number
   :noindex:

.. autoattribute:: abjad.tools.pitchtools.NumberedInterval.NumberedInterval.NumberedInterval.numbered_interval_number
   :noindex:

.. autoattribute:: abjad.tools.pitchtools.NumberedInterval.NumberedInterval.NumberedInterval.semitones
   :noindex:

Class methods
-------------

.. automethod:: abjad.tools.pitchtools.NumberedInterval.NumberedInterval.NumberedInterval.from_pitch_carriers
   :noindex:

Static methods
--------------

.. automethod:: abjad.tools.pitchtools.NumberedInterval.NumberedInterval.NumberedInterval.is_named_interval_abbreviation
   :noindex:

.. automethod:: abjad.tools.pitchtools.NumberedInterval.NumberedInterval.NumberedInterval.is_named_interval_quality_abbreviation
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.pitchtools.NumberedInterval.NumberedInterval.NumberedInterval.__abs__
   :noindex:

.. automethod:: abjad.tools.pitchtools.NumberedInterval.NumberedInterval.NumberedInterval.__add__
   :noindex:

.. automethod:: abjad.tools.pitchtools.NumberedInterval.NumberedInterval.NumberedInterval.__copy__
   :noindex:

.. automethod:: abjad.tools.pitchtools.NumberedInterval.NumberedInterval.NumberedInterval.__eq__
   :noindex:

.. automethod:: abjad.tools.pitchtools.NumberedInterval.NumberedInterval.NumberedInterval.__float__
   :noindex:

.. automethod:: abjad.tools.pitchtools.NumberedInterval.NumberedInterval.NumberedInterval.__ge__
   :noindex:

.. automethod:: abjad.tools.pitchtools.NumberedInterval.NumberedInterval.NumberedInterval.__gt__
   :noindex:

.. automethod:: abjad.tools.pitchtools.NumberedInterval.NumberedInterval.NumberedInterval.__hash__
   :noindex:

.. automethod:: abjad.tools.pitchtools.NumberedInterval.NumberedInterval.NumberedInterval.__int__
   :noindex:

.. automethod:: abjad.tools.pitchtools.NumberedInterval.NumberedInterval.NumberedInterval.__le__
   :noindex:

.. automethod:: abjad.tools.pitchtools.NumberedInterval.NumberedInterval.NumberedInterval.__lt__
   :noindex:

.. automethod:: abjad.tools.pitchtools.NumberedInterval.NumberedInterval.NumberedInterval.__ne__
   :noindex:

.. automethod:: abjad.tools.pitchtools.NumberedInterval.NumberedInterval.NumberedInterval.__neg__
   :noindex:

.. automethod:: abjad.tools.pitchtools.NumberedInterval.NumberedInterval.NumberedInterval.__repr__
   :noindex:

.. automethod:: abjad.tools.pitchtools.NumberedInterval.NumberedInterval.NumberedInterval.__str__
   :noindex:

.. automethod:: abjad.tools.pitchtools.NumberedInterval.NumberedInterval.NumberedInterval.__sub__
   :noindex:
